@@ -7,8 +7,8 @@ Example:
 """
 import typer
 
+from labby.commands.common import get_labby_objs_from_node
 from labby import utils
-from labby import config
 
 
 app = typer.Typer(help="Runs Restart actions on Network Provider Lab Resources")
@@ -26,15 +26,8 @@ def node(
 
     > labby restart node r1 --project lab01
     """
-    provider = config.get_provider()
-    project = provider.search_project(project_name=project_name)
-    if not project:
-        utils.console.log(f"Project [cyan i]{project_name}[/] not found. Nothing to do...", style="error")
-        raise typer.Exit(1)
-    device = project.search_node(name=node_name)
-    if not device:
-        utils.console.log(f"Node [cyan i]{node_name}[/] not found. Nothing to do...", style="error")
-        raise typer.Exit(1)
+    # Get Labby objects from project and node definition
+    _, _, device = get_labby_objs_from_node(project_name=project_name, node_name=node_name)
 
     # Restart node
     device.restart()
